#
# spec file for package libuna
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if "" != ""
%define pprefix @BUILD_FLAVOR@-
%define psuffix -@BUILD_FLAVOR@
%else
%define psuffix %nil
%endif
%define lname libuna1

Name:           libuna%psuffix
Version:        20240414
Release:        1.3
Summary:        Library to support Unicode and ASCII (byte string) conversions
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libuna/
Source:         https://github.com/libyal/libuna/releases/download/%version/libuna-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libuna/releases/download/%version/libuna-alpha-%version.tar.gz.asc
Source3:        libuna.keyring
Source99:       libuna-rpmlintrc
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcdatetime) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
%if "" != "mini"
BuildRequires:  pkgconfig(libcfile) >= 20240414
%endif
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
# Various notes: https://en.opensuse.org/libyal

%description
libuna is a library to support Unicode and ASCII (byte string)
conversions. It currently supports: 7-bit ASCII, ISO 8859-{1..15},
Windows 874, 932, 936, 949, 950, 1250, 1251, 1252, 1253, 1254, 1255,
1256, 1257, 1258, KOI8-R, KOI8-U, UTF-7, UTF-8, UTF-16, UTF-32.

%package -n %lname%psuffix
Summary:        Library to support Unicode and ASCII (byte string) conversions
Group:          System/Libraries
%if "" == ""
Obsoletes:      %lname-mini
%endif

%description -n %lname%psuffix
libuna is a library to support Unicode and ASCII (byte string)
conversions.

%package tools
Summary:        Utilities from libuna for Unicode/ASCII Byte Stream conversions
Group:          Development/Tools/Other

%description tools
Several tools for converting Unicode and ASCII (byte stream) based text.

%package devel
Summary:        Development files for libuna, a library to support Unicode/ASCII conversions
Group:          Development/Libraries/C and C++
Requires:       %lname%psuffix = %version
%if "" == ""
Obsoletes:      libuna-mini-devel
%endif

%description devel
libuna is a library to support Unicode and ASCII (byte string)
conversions.

This subpackage contains libraries and header files for developing
applications that want to make use of libuna.

%prep
%autosetup -p1 -n libuna-%version

%build
echo "V_%version { global: *; };" >v.sym
%configure \
%if "" == "mini"
	--disable-tools \
%endif
	--disable-static --enable-wide-character-type \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
%if "" != "mini"
grep '  local' config.log && exit 1
%endif
%make_build

%install
%make_install
b="%buildroot"
rm -f "$b/%_libdir"/*.la
%if "" == "mini"
rm -Rf "$b/%_bindir" "$b/%_mandir/man1"
%endif

%ldconfig_scriptlets -n %lname%psuffix

%files -n %lname%psuffix
%license COPYING
%_libdir/libuna.so.1*

%if "" != "mini"
%files tools
%_bindir/una*
%_mandir/man1/unaexport.1*
%endif

%files devel
%_includedir/libuna*
%_libdir/libuna.so
%_libdir/pkgconfig/libuna.pc
%_mandir/man3/libuna.3*

%changelog
* Sun Apr 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240414
  * No changelog was provided
* Tue Jan 30 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240130
  * No user-visible changes
* Wed Jul 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230710
  * Changes to support UTF-16 stream unpaired surrogates
* Mon Jul  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230702
  * Added support to allow UTF-16 stream unpaired surrogates
  * Added support for 6-byte UTF-8
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sat Jun 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220611
  * A bunch of new functions, but no proper changelog available.
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Add libuna-rpmlintrc for shlib-policy-name-error
* Sun Jan  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220102
  * Unspecified improvements to Mac OS codepage support and tests.
* Thu Nov 25 2021 Jan Engelhardt <jengelh@inai.de>
- Unconditionally run autoreconf because of patches
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210801
  * No changelog was provided
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210418 (2939fe8f)
  * No changelog was provided
- Add system-libs.patch
* Sun Dec 13 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201204
  * changes to handle high range surrogates
  * added SCSU support
* Mon Mar 25 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190102
  * updates to UTF-8, UTF-16, and UTF-32 strings
  * updates to base32 support
  * updates to compare functions
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- update to v0~20170825
  * small fixes
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- update to v0~20170112
- Remove BuildRequires libcsystem, libcstring
- Use libcerror from factory
* Sun Jan 31 2016 Greg.Freemyer@gmail.com
- update to v0~20150927
  * merged history from backups
  * updated m4 scripts and msvscpp files
  * worked on tests
  * Changes for gcc 5 support
* Mon Jan  5 2015 Greg.Freemyer@gmail.com
- update to v0~20150101
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcdatetime from OBS, not internal version
- start using libcsystem from OBS, not internal version
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
-  update to v0~20140105
  * 2014 update
  * updated dependencies
  * worked on libcdatetime support
  * code clean up
  * worked on tests
* Wed Oct 23 2013 Greg.Freemyer@gmail.com
- update to v0~20130728
  * fixes for some stream functions being too strict
- fix version numbers on dependancies to not have 0~ in them
* Sat Jul 27 2013 Greg.Freemyer@gmail.com
- update to v0~20130609
  * fix in .pc.in file
  * updated dependencies
  * fixes issues for building with stand-alone version of libcnotify
  * removed date time functionality from libcsystem
- change to gz compression for tarball to eliminate conversion from download
- use libyal libraries from factory where posible, not internal versions
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- run spec-cleaner
- add comments about why internal libraries are being used
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20130103) for build.opensuse.org
